package MlFront_Core

  1. Overview
  2. Docs

Module MlFront_CoreSource

Sourcemodule EnvMods : sig ... end
Sourcemodule FilePath : sig ... end

The FilePath module manipulates and accesses file paths in a manner portable across operating systems. The design guarantee is that operations on the FilePath paths are deterministic, and the operations arrive at the same answer regardless of the host machine.

Sourcemodule LibraryId : sig ... end

Library identifiers.

Sourcemodule MlFrontConstants : sig ... end
Sourcemodule ModuleAssumptions : sig ... end
Sourcemodule ModuleId : sig ... end

A ModuleId identifies a module that a developer can create on the file system (aka. a "compilation unit").

Sourcemodule ModuleParsing : sig ... end
Sourcemodule PackageId : sig ... end

Package identifiers.

Sourcemodule Party : sig ... end
Sourcemodule ProxyModuleId : sig ... end

A ProxyModuleId is-a SpecialModuleId.

Sourcemodule QualifiedModuleName : sig ... end

QualifiedModuleName provides operations to compress a standard module identifier. The compression can significantly reduce pressure on limited path-length file systems like 260-char Windows.

Sourcemodule SpecialModuleId : sig ... end

A SpecialModuleId is-a ModuleId.

Sourcemodule StandardModuleId : sig ... end

A StandardModuleId is-a ModuleId.

Sourcemodule UnitId : sig ... end

Unit ids are modules that can appear in the filesystem, whether or not a developer wrote the module or MlFront generated the module or the module has been bundled with many others into a library archive. All modules ids and all package ids are unit ids.

Sourcemodule UnitMods : sig ... end

The module UnitMods represents the ordered list of modifications to a compilation unit like opening modules and adding alerts that result from a MlFront analysis of the project.