package MlFront_Core

  1. Overview
  2. Docs

Module MlFront_Core.ModuleAssumptionsSource

Sourceval mlfront_standard_namespace_terms_cannot_have_double_underscores : unit -> unit

Module names in OCaml with double underscores are treated specially by Merlin and other tools; they are treated as if dots have replaced the double underscores. No segment of a standard module may have a double underscore.

Sourceval mlfront_library_names_cannot_have_double_underscores : unit -> unit

Module names in OCaml with double underscores are treated specially by Merlin and other tools; they are treated as if dots have replaced the double underscores. A library name may not have a double underscore.

Sourceval mlfront_module_charset_does_not_have_quote : unit -> unit

MlFront module names must not have single quote characters since quote is the only character outside of A-Za-z0-9_ that is supported by codept. Actually, the - character is also supported by codept, but its Support.is_valid_module_char states that ocamlopt can compile it but emits a warning.