package MlFront_Core

  1. Overview
  2. Docs

Module MlFront_Core.ProxyModuleIdSource

A ProxyModuleId is-a SpecialModuleId.

Sourcetype t
Sourceval of_standard_module_id : StandardModuleId.t -> t
Sourceval show_dot : t -> string

show_dot module_id returns a string with the library concatenated with a dot (.) and then concatenated with the module id path separated by dots. The module id path will end with a ModuleParsing.proxy_suffix.

Accessors

Sourceval standard_module_id : t -> StandardModuleId.t

standard_module_id t is the accessor of the standard module id component of the t proxy module.

Casting

Sourceval cast_as_special_module_id : t -> SpecialModuleId.t

cast_as_special_module_id special_module_id is the module special_module_id upcast to a SpecialModuleId.t.

Sourceval downcast_special_module_id : SpecialModuleId.t -> t option

downcast_special_module_id special_module_id tries to convert the special module identifier special_module_id to a proxy module id.