Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Page
Library
Module
Module type
Parameter
Class
Class type
MlFront_CoreSourceThe FilePath module manipulates and accesses file paths in a manner portable across operating systems. The design guarantee is that operations on the FilePath paths are deterministic, and the operations arrive at the same answer regardless of the host machine.
A ModuleId identifies a module that a developer can create on the file system (aka. a "compilation unit").
A ProxyModuleId is-a SpecialModuleId.
QualifiedModuleName provides operations to compress a standard module identifier. The compression can significantly reduce pressure on limited path-length file systems like 260-char Windows.
A SpecialModuleId is-a ModuleId.
A StandardModuleId is-a ModuleId.
Unit ids are modules that can appear in the filesystem, whether or not a developer wrote the module or MlFront generated the module or the module has been bundled with many others into a library archive. All modules ids and all package ids are unit ids.