parse_exn library creates the library identifier for the library named library.
Raises Invalid_argument when the library is not a valid MlFront library name.
The library "ZzZz_Zz" is reserved for internal dk and MlFront use for which parse_exn will raise Invalid_argument, unless the ~allow_reserved:() flag is used.
The library "ZzZz_Zz" which is reserved for internal dk and MlFront use.
Special Library Suffixes
A name can be dedicated to a special module for the convenience of build systems. These names are formed by taking the library that the special module belongs to, and adding a suffix.
Library with these suffixes are not MlFront library modules (ex. "DkHelloScript_Std") or MlFront standard modules (ex. "Example001"). They should never be part of a codept analysis and it is an error for code to reference them. But they can form valid OCaml module names (ex. "Example001O__") recognized by both ocamlc and Dune.
And they can also form valid Dune library names (which don't allow single quotes).