Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Page
Library
Module
Module type
Parameter
Class
Class type
MlFront_Core.ModuleAssumptionsSourceModule names in OCaml with double underscores are treated specially by Merlin and other tools; they are treated as if dots have replaced the double underscores. No segment of a standard module may have a double underscore.
Module names in OCaml with double underscores are treated specially by Merlin and other tools; they are treated as if dots have replaced the double underscores. A library name may not have a double underscore.
MlFront module names must not have single quote characters since quote is the only character outside of A-Za-z0-9_ that is supported by codept. Actually, the - character is also supported by codept, but its Support.is_valid_module_char states that ocamlopt can compile it but emits a warning.