Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Page
Library
Module
Module type
Parameter
Class
Class type
MlFront_Core.ProxyModuleIdSourceA ProxyModuleId is-a SpecialModuleId.
show_dot module_id returns a string with the library concatenated with a dot (.) and then concatenated with the module id path separated by dots. The module id path will end with a ModuleParsing.proxy_suffix.
standard_module_id t is the accessor of the standard module id component of the t proxy module.
cast_as_special_module_id special_module_id is the module special_module_id upcast to a SpecialModuleId.t.
downcast_special_module_id special_module_id tries to convert the special module identifier special_module_id to a proxy module id.